# Monoco Kanban

> **Note**: The primary documentation for this module is in Chinese. Please refer to [README_ZH.md](./README_ZH.md).

## Introduction

Monoco Kanban is a **Git-Native Project Management Client** designed to provide a "Linear-like" experience for the "Task as Code" philosophy.

Unlike traditional SaaS tools, it operates directly on your local file system (`Issues/` directory), using Git as the source of truth for all task states.

## Documentation

- [Product Vision (Vision)](./docs/zh/00-vision.md)
- [Architecture (Architecture)](./docs/zh/01-architecture.md)
- [Identity & Security (Identity)](./docs/zh/02-identity.md)
